@@ -44,10 +44,20 @@ struct GnomeCmdChownDialogPrivate
 G_DEFINE_TYPE (GnomeCmdChownDialog, gnome_cmd_chown_dialog, GNOME_CMD_TYPE_DIALOG)
 
 
-static void do_chown (GnomeCmdFile *in, uid_t uid, gid_t gid, gboolean recurse)
+enum
+{
+    OWNER_CHANGED,
+    LAST_SIGNAL
+};
+
+
+static guint signals[LAST_SIGNAL] = { 0 };
+
+
+static void do_chown (GnomeCmdChownDialog *dialog, GnomeCmdFile *in, uid_t uid, gid_t gid, gboolean recurse)
 {
     g_return_if_fail (in != nullptr);
-    g_return_if_fail (in->gFileInfo != nullptr);
+    g_return_if_fail (in->get_file_info() != nullptr);
     GError *error = nullptr;
 
     if(!in->chown(uid, gid, &error))
@@ -66,17 +76,17 @@ static void do_chown (GnomeCmdFile *in, uid_t uid, gid_t gid, gboolean recurse)
     {
         GnomeCmdDir *dir = gnome_cmd_dir_ref (GNOME_CMD_DIR (in));
 
-        gnome_cmd_dir_list_files (dir, FALSE);
+        gnome_cmd_dir_list_files (GTK_WINDOW (dialog), dir, FALSE);
 
         for (GList *i = gnome_cmd_dir_get_files (dir); i; i = i->next)
         {
             GnomeCmdFile *f = (GnomeCmdFile *) i->data;
 
-            auto filename = get_gfile_attribute_string(f->gFile, G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME);
+            auto filename = get_gfile_attribute_string(f->get_file(), G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME);
             if (!f->is_dotdot && strcmp (filename, ".") != 0
-                && !g_file_info_get_is_symlink(f->gFileInfo))
+                && !g_file_info_get_is_symlink(f->get_file_info()))
             {
-                do_chown (f, uid, gid, TRUE);
+                do_chown (dialog, f, uid, gid, TRUE);
             }
             g_free(filename);
         }
@@ -112,20 +122,20 @@ static void on_ok (GtkButton *button, GnomeCmdChownDialog *dialog)
         g_return_if_fail (f != NULL);
 
         //ToDo: Check if this works also on non-local filesystems
-        do_chown (f, uid, gid, recurse);
+        do_chown (dialog, f, uid, gid, recurse);
     }
 
-    view_refresh (NULL, NULL);
+    g_signal_emit (dialog, signals[OWNER_CHANGED], 0);
 
     gnome_cmd_file_list_free (dialog->priv->files);
-    gtk_widget_destroy (GTK_WIDGET (dialog));
+    gtk_window_destroy (GTK_WINDOW (dialog));
 }
 
 
 static void on_cancel (GtkButton *button, GnomeCmdChownDialog *dialog)
 {
     gnome_cmd_file_list_free (dialog->priv->files);
-    gtk_widget_destroy (GTK_WIDGET (dialog));
+    gtk_window_destroy (GTK_WINDOW (dialog));
 }
 
 
@@ -144,6 +154,16 @@ static void gnome_cmd_chown_dialog_class_init (GnomeCmdChownDialogClass *klass)
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
     object_class->finalize = gnome_cmd_chown_dialog_finalize;
+
+    signals[OWNER_CHANGED] =
+        g_signal_new ("owner-changed",
+            G_TYPE_FROM_CLASS (klass),
+            G_SIGNAL_RUN_LAST,
+            G_STRUCT_OFFSET (GnomeCmdChownDialogClass, owner_changed),
+            nullptr, nullptr,
+            g_cclosure_marshal_VOID__POINTER,
+            G_TYPE_NONE,
+            1, G_TYPE_POINTER);
 }
 
 
@@ -154,7 +174,7 @@ static void gnome_cmd_chown_dialog_init (GnomeCmdChownDialog *dialog)
 
     dialog->priv = g_new0 (GnomeCmdChownDialogPrivate, 1);
 
-    gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, FALSE, FALSE);
+    gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
     gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
     gtk_window_set_title (GTK_WINDOW (dialog), _("Chown"));
 
@@ -162,16 +182,14 @@ static void gnome_cmd_chown_dialog_init (GnomeCmdChownDialog *dialog)
     gnome_cmd_dialog_add_expanding_category (GNOME_CMD_DIALOG (dialog), vbox);
 
     dialog->priv->chown_component = gnome_cmd_chown_component_new ();
-    g_object_ref (dialog->priv->chown_component);
-    g_object_set_data_full (G_OBJECT (dialog), "chown_component", dialog->priv->chown_component, g_object_unref);
     gtk_widget_show (dialog->priv->chown_component);
-    gtk_box_pack_start (GTK_BOX (vbox), dialog->priv->chown_component, FALSE, FALSE, 0);
+    gtk_box_append (GTK_BOX (vbox), dialog->priv->chown_component);
 
     dialog->priv->recurse_check = create_check (GTK_WIDGET (dialog), _("Apply Recursively"), "check");
-    gtk_box_pack_start (GTK_BOX (vbox), dialog->priv->recurse_check, FALSE, FALSE, 0);
+    gtk_box_append (GTK_BOX (vbox), dialog->priv->recurse_check);
 
-    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_SIGNAL_FUNC (on_cancel), dialog);
-    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_OK, GTK_SIGNAL_FUNC (on_ok), dialog);
+    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), _("_Cancel"), G_CALLBACK (on_cancel), dialog);
+    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), _("_OK"), G_CALLBACK (on_ok), dialog);
 }
 
 
@@ -188,8 +206,8 @@ GtkWidget *gnome_cmd_chown_dialog_new (GList *files)
     GnomeCmdFile *f = GNOME_CMD_FILE (dialog->priv->files->data);
 
     gnome_cmd_chown_component_set (GNOME_CMD_CHOWN_COMPONENT (dialog->priv->chown_component),
-        get_gfile_attribute_uint32(f->gFile, G_FILE_ATTRIBUTE_UNIX_UID),
-        get_gfile_attribute_uint32(f->gFile, G_FILE_ATTRIBUTE_UNIX_GID));
+        get_gfile_attribute_uint32(f->get_file(), G_FILE_ATTRIBUTE_UNIX_UID),
+        get_gfile_attribute_uint32(f->get_file(), G_FILE_ATTRIBUTE_UNIX_GID));
 
     return GTK_WIDGET (dialog);
 }
