@@ -36,11 +36,14 @@ using namespace std;
 #define GNOME_CMD_IS_CONNECT_DIALOG(obj)      (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_CMD_TYPE_CONNECT_DIALOG)
 
 
+GType gnome_cmd_connect_dialog_get_type ();
+
+
 struct GnomeCmdConnectDialog
 {
     GtkDialog parent;
 
-    class Private;
+    struct Private;
 
     Private *priv;
 
@@ -63,8 +66,8 @@ struct GnomeCmdConnectDialog::Private
     string *alias {nullptr};
     string uri_str;
 
-    GtkWidget *required_table {nullptr};
-    GtkWidget *optional_table {nullptr};
+    GtkGrid *required_grid {nullptr};
+    GtkGrid *optional_grid {nullptr};
 
     GtkWidget *type_combo {nullptr};
 
@@ -79,7 +82,7 @@ struct GnomeCmdConnectDialog::Private
     ~Private();
 
     void setup_for_type();
-    void show_entry(GtkWidget *table, GtkWidget *entry, const gchar *text, gint &i);
+    void show_entry(GtkGrid *grid, GtkWidget *entry, const gchar *text, gint &i);
 };
 
 
@@ -121,42 +124,47 @@ inline GnomeCmdConnectDialog::Private::~Private()
 }
 
 
+static void remove_grid_child (GtkWidget *child, gpointer user_data)
+{
+    gtk_container_remove (GTK_CONTAINER (user_data), child);
+}
+
+
 void GnomeCmdConnectDialog::Private::setup_for_type()
 {
     gint type = gtk_combo_box_get_active (GTK_COMBO_BOX (type_combo));
 
     if (gtk_widget_get_parent (alias_entry))
-        gtk_container_remove (GTK_CONTAINER (required_table), alias_entry);
+        gtk_container_remove (GTK_CONTAINER (required_grid), alias_entry);
 
     if (gtk_widget_get_parent (uri_entry))
-        gtk_container_remove (GTK_CONTAINER (required_table), uri_entry);
+        gtk_container_remove (GTK_CONTAINER (required_grid), uri_entry);
 
     if (gtk_widget_get_parent (server_entry))
-        gtk_container_remove (GTK_CONTAINER (required_table), server_entry);
+        gtk_container_remove (GTK_CONTAINER (required_grid), server_entry);
 
     if (gtk_widget_get_parent (port_entry))
-        gtk_container_remove (GTK_CONTAINER (optional_table), port_entry);
+        gtk_container_remove (GTK_CONTAINER (optional_grid), port_entry);
 
     if (gtk_widget_get_parent (folder_entry))
-        gtk_container_remove (GTK_CONTAINER (optional_table), folder_entry);
+        gtk_container_remove (GTK_CONTAINER (optional_grid), folder_entry);
 
     if (gtk_widget_get_parent (domain_entry))
-        gtk_container_remove (GTK_CONTAINER (optional_table), domain_entry);
+        gtk_container_remove (GTK_CONTAINER (optional_grid), domain_entry);
 
     // Destroy all labels
-    gtk_container_foreach (GTK_CONTAINER (required_table), (GtkCallback) gtk_widget_destroy, NULL);
+    gtk_container_foreach (GTK_CONTAINER (required_grid), (GtkCallback) remove_grid_child, required_grid);
 
     gint i = 1;
-    GtkWidget *table = required_table;
 
     gboolean show_port, show_domain;
 
-    show_entry (table, alias_entry, _("_Alias:"), i);
+    show_entry (required_grid, alias_entry, _("_Alias:"), i);
 
     switch (type)
     {
         case CON_URI:
-            show_entry (table, uri_entry, _("_Location (URI):"), i);
+            show_entry (required_grid, uri_entry, _("_Location (URI):"), i);
             return;
 
         default:
@@ -181,60 +189,51 @@ void GnomeCmdConnectDialog::Private::setup_for_type()
 #endif
     }
 
-    show_entry (table, server_entry, _("_Server:"), i);
-
-    GtkWidget *align;
-
-    align = gtk_alignment_new (0.0, 0.0, 1.0, 1.0);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (align), 12, 0, 0, 0);
-    gtk_table_attach (GTK_TABLE (table), align, 0, 2, i, i+1, GTK_FILL, GTK_FILL, 0, 0);
-    gtk_widget_show (align);
-
-    i++;
+    show_entry (required_grid, server_entry, _("_Server:"), i);
 
     gchar *str = g_strdup_printf ("<b>%s</b>", _("Optional information"));
     GtkWidget *label = gtk_label_new (str);
     g_free (str);
 
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+    gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
     gtk_widget_show (label);
-    gtk_container_add (GTK_CONTAINER (align), label);
+    gtk_widget_set_margin_top (label, 12);
+    gtk_grid_attach (required_grid, label, 0, i, 2, 1);
+    i++;
 
-    align = gtk_alignment_new (0.0, 0.0, 1.0, 1.0);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (align), 0, 0, 12, 0);
-    gtk_table_attach (GTK_TABLE (table), align, 0, 2, i, i+1, GTK_FILL, GTK_FILL, 0, 0);
-    gtk_widget_show (align);
-
-
-    optional_table = table = gtk_table_new (1, 2, FALSE);
-    gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 12);
-    gtk_widget_show (table);
-    gtk_container_add (GTK_CONTAINER (align), table);
+    optional_grid = GTK_GRID (gtk_grid_new ());
+    gtk_grid_set_row_spacing (optional_grid, 6);
+    gtk_grid_set_column_spacing (optional_grid, 12);
+    gtk_widget_show (GTK_WIDGET (optional_grid));
+    gtk_widget_set_margin_start (GTK_WIDGET (optional_grid), 12);
+    gtk_grid_attach (required_grid, GTK_WIDGET (optional_grid), 0, i, 2, 1);
 
     i = 0;
 
     if (show_port)
-        show_entry (table, port_entry, _("_Port:"), i);
+        show_entry (optional_grid, port_entry, _("_Port:"), i);
 
-    show_entry (table, folder_entry, _("_Folder:"), i);
+    show_entry (optional_grid, folder_entry, _("_Folder:"), i);
 
     if (show_domain)
-        show_entry (table, domain_entry, _("_Domain name:"), i);
+        show_entry (optional_grid, domain_entry, _("_Domain name:"), i);
 }
 
 
-inline void GnomeCmdConnectDialog::Private::show_entry(GtkWidget *table, GtkWidget *entry, const gchar *text, gint &i)
+inline void GnomeCmdConnectDialog::Private::show_entry(GtkGrid *grid, GtkWidget *entry, const gchar *text, gint &i)
 {
     GtkWidget *label = gtk_label_new_with_mnemonic (text);
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+    gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
     gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1, GTK_FILL, GTK_FILL, 0, 0);
+    gtk_grid_attach (GTK_GRID (grid), label, 0, i, 1, 1);
 
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
     gtk_widget_show (entry);
-    gtk_table_attach (GTK_TABLE (table), entry, 1, 2, i, i+1, GtkAttachOptions (GTK_FILL | GTK_EXPAND), GTK_FILL, 0, 0);
+    gtk_widget_set_hexpand (entry, TRUE);
+    gtk_grid_attach (GTK_GRID (grid), entry, 1, i, 1, 1);
 
     ++i;
 }
@@ -292,14 +291,8 @@ gboolean GnomeCmdConnectDialog::verify_uri()
     return TRUE;
 }
 
-#if defined (__GNUC__)
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wmissing-declarations"
-#endif
+
 G_DEFINE_TYPE (GnomeCmdConnectDialog, gnome_cmd_connect_dialog, GTK_TYPE_DIALOG)
-#if defined (__GNUC__)
-#pragma GCC diagnostic pop
-#endif
 
 
 static void gnome_cmd_connect_dialog_finalize (GObject *object)
@@ -366,9 +359,7 @@ static void port_insert_text (GtkEditable *editable, const gchar *new_text, gint
 
 static void gnome_cmd_connect_dialog_init (GnomeCmdConnectDialog *dialog)
 {
-    GtkWidget *align;
     GtkWidget *label;
-    GtkWidget *table;
     GtkWidget *combo;
     GtkWidget *hbox;
     GtkWidget *vbox;
@@ -378,18 +369,22 @@ static void gnome_cmd_connect_dialog_init (GnomeCmdConnectDialog *dialog)
     g_return_if_fail (dialog->priv != NULL);
 
     gtk_window_set_title (*dialog, _("Remote Server"));
-    gtk_dialog_set_has_separator (*dialog, FALSE);
-    gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-    gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 2);
     gtk_window_set_resizable (*dialog, FALSE);
 
-    vbox = gtk_vbox_new (FALSE, 6);
-    gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
-    gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), vbox, FALSE, TRUE, 0);
+    GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
+    gtk_widget_set_margin_top (content_area, 10);
+    gtk_widget_set_margin_bottom (content_area, 10);
+    gtk_widget_set_margin_start (content_area, 10);
+    gtk_widget_set_margin_end (content_area, 10);
+    gtk_box_set_spacing (GTK_BOX (content_area), 6);
+
+    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+    gtk_box_append (GTK_BOX (content_area), vbox);
     gtk_widget_show (vbox);
 
-    hbox = gtk_hbox_new (FALSE, 6);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 0);
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+    gtk_box_append (GTK_BOX (vbox), hbox);
     gtk_widget_show (hbox);
 
     gchar *str = g_strdup_printf ("<b>%s</b>", _("Service _type:"));
@@ -397,56 +392,47 @@ static void gnome_cmd_connect_dialog_init (GnomeCmdConnectDialog *dialog)
     g_free (str);
 
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+    gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
     gtk_widget_show (label);
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    gtk_box_append (GTK_BOX (hbox), label);
 
-    dialog->priv->type_combo = combo = gtk_combo_box_new_text ();
+    dialog->priv->type_combo = combo = gtk_combo_box_text_new ();
 
     // Keep this in sync with enum ConnectionMethodID in gnome-cmd-con.h
-    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("SSH"));
-    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("FTP (with login)"));
-    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Public FTP"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("SSH"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("FTP (with login)"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("Public FTP"));
 #ifdef HAVE_SAMBA
-    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Windows share"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("Windows share"));
 #endif
-    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("WebDAV (HTTP)"));
-    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Secure WebDAV (HTTPS)"));
-    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Custom location"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("WebDAV (HTTP)"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("Secure WebDAV (HTTPS)"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("Custom location"));
     gtk_widget_show (combo);
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), combo);
-    gtk_box_pack_start (GTK_BOX (hbox), combo, TRUE, TRUE, 0);
+    gtk_box_append (GTK_BOX (hbox), combo);
     g_signal_connect (combo, "changed", G_CALLBACK (dlg_changed_callback), dialog);
 
-    align = gtk_alignment_new (0.0, 0.0, 1.0, 1.0);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (align), 0, 0, 12, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), align, TRUE, TRUE, 0);
-    gtk_widget_show (align);
-
-    hbox = gtk_hbox_new (FALSE, 6);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 0);
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+    gtk_box_append (GTK_BOX (vbox), hbox);
     gtk_widget_show (hbox);
 
-    align = gtk_alignment_new (0.0, 0.0, 1.0, 1.0);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (align), 0, 0, 12, 0);
-    gtk_box_pack_start (GTK_BOX (hbox), align, TRUE, TRUE, 0);
-    gtk_widget_show (align);
-
-
-    dialog->priv->required_table = table = gtk_table_new (1, 2, FALSE);
-    gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 12);
-    gtk_widget_show (table);
-    gtk_container_add (GTK_CONTAINER (align), table);
+    dialog->priv->required_grid = GTK_GRID (gtk_grid_new ());
+    gtk_grid_set_row_spacing (dialog->priv->required_grid, 6);
+    gtk_grid_set_column_spacing (dialog->priv->required_grid, 12);
+    gtk_widget_show (GTK_WIDGET (dialog->priv->required_grid));
+    gtk_widget_set_margin_start (GTK_WIDGET (dialog->priv->required_grid), 12);
+    gtk_box_append (GTK_BOX (hbox), GTK_WIDGET (dialog->priv->required_grid));
 
     g_signal_connect (dialog->priv->port_entry, "insert-text", G_CALLBACK (port_insert_text), NULL);
 
     dialog->priv->setup_for_type();
 
     gtk_dialog_add_buttons (*dialog,
-                            GTK_STOCK_HELP, GTK_RESPONSE_HELP,
-                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                            GTK_STOCK_OK, GTK_RESPONSE_OK,
+                            _("_Help"), GTK_RESPONSE_HELP,
+                            _("_Cancel"), GTK_RESPONSE_CANCEL,
+                            _("_OK"), GTK_RESPONSE_OK,
                             NULL);
 
     gtk_dialog_set_default_response (*dialog, GTK_RESPONSE_OK);
@@ -486,7 +472,7 @@ GnomeCmdConRemote *gnome_cmd_connect_dialog_new (gboolean has_alias)
         con->method = (ConnectionMethodID) gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->priv->type_combo));
     }
 
-    gtk_widget_destroy (*dialog);
+    gtk_window_destroy (GTK_WINDOW (dialog));
 
     return server;
 }
@@ -496,7 +482,7 @@ gboolean gnome_cmd_connect_dialog_edit (GnomeCmdConRemote *server)
 {
     g_return_val_if_fail (server != nullptr, FALSE);
 
-    auto *dialog = reinterpret_cast<GnomeCmdConnectDialog*> (gtk_widget_new (GNOME_CMD_TYPE_CONNECT_DIALOG, nullptr));
+    auto *dialog = reinterpret_cast<GnomeCmdConnectDialog*> (g_object_new (GNOME_CMD_TYPE_CONNECT_DIALOG, nullptr));
     g_return_val_if_fail (dialog != nullptr, FALSE);
 
     auto *con = GNOME_CMD_CON (server);
@@ -506,28 +492,28 @@ gboolean gnome_cmd_connect_dialog_edit (GnomeCmdConRemote *server)
     if (con->alias)
     {
         dialog->priv->alias = new string(con->alias);
-        gtk_entry_set_text (GTK_ENTRY (dialog->priv->alias_entry), con->alias);
+        gtk_editable_set_text (GTK_EDITABLE (dialog->priv->alias_entry), con->alias);
     }
     else
         gtk_widget_set_sensitive (dialog->priv->alias_entry, FALSE);
 
-     auto host = g_strdup(gnome_cmd_con_get_host_name(con));
-     gint port = gnome_cmd_con_get_port (con);
-     auto path = gnome_cmd_con_get_root_path(con);
+    auto host = g_strdup(gnome_cmd_con_get_host_name(con));
+    gint port = gnome_cmd_con_get_port (con);
+    auto path = gnome_cmd_con_get_root_path(con);
 
     if (con->uri)
     {
         dialog->priv->uri_str = con->uri;
 
-        gtk_entry_set_text (GTK_ENTRY (dialog->priv->uri_entry), con->uri);
+        gtk_editable_set_text (GTK_EDITABLE (dialog->priv->uri_entry), con->uri);
 
-        gtk_entry_set_text (GTK_ENTRY (dialog->priv->server_entry), host);
+        gtk_editable_set_text (GTK_EDITABLE (dialog->priv->server_entry), host);
 
         if (path)
-            gtk_entry_set_text (GTK_ENTRY (dialog->priv->folder_entry), path);
+            gtk_editable_set_text (GTK_EDITABLE (dialog->priv->folder_entry), path);
 
         if (port != -1)
-            gtk_entry_set_text (GTK_ENTRY (dialog->priv->port_entry), stringify(port).c_str());
+            gtk_editable_set_text (GTK_EDITABLE (dialog->priv->port_entry), stringify(port).c_str());
     }
 
     gint response = gtk_dialog_run (*dialog);
@@ -568,9 +554,9 @@ gboolean gnome_cmd_connect_dialog_edit (GnomeCmdConRemote *server)
         }
         else
         {
-            host = g_strdup(gtk_entry_get_text (GTK_ENTRY (dialog->priv->server_entry)));
-            path = g_strdup(gtk_entry_get_text (GTK_ENTRY (dialog->priv->folder_entry)));
-            auto portChar = gtk_entry_get_text (GTK_ENTRY (dialog->priv->port_entry));
+            host = g_strdup(gtk_editable_get_text (GTK_EDITABLE (dialog->priv->server_entry)));
+            path = g_strdup(gtk_editable_get_text (GTK_EDITABLE (dialog->priv->folder_entry)));
+            auto portChar = gtk_editable_get_text (GTK_EDITABLE (dialog->priv->port_entry));
             port = portChar ? atoi(portChar) : -1;
 
             gnome_cmd_con_set_base_path(con, path && strlen(path) > 0
@@ -588,10 +574,9 @@ gboolean gnome_cmd_connect_dialog_edit (GnomeCmdConRemote *server)
         auto alias = dialog->priv->alias ? dialog->priv->alias->c_str() : nullptr;
         gnome_cmd_con_set_alias (con, alias);
         con->method = (ConnectionMethodID) gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->priv->type_combo));
-        gnome_cmd_con_remote_set_tooltips (server, host);
     }
 
-    gtk_widget_destroy (*dialog);
+    gtk_window_destroy (GTK_WINDOW (dialog));
 
     return response==GTK_RESPONSE_OK;
 }
