@@ -37,7 +37,8 @@
 #include "filter.h"
 #include "history.h"
 #include "dict.h"
-#include "tuple.h"
+
+#include <tuple>
 
 #define GCMD_TYPE_SETTINGS (gcmd_settings_get_type ())
 
@@ -52,7 +53,6 @@ GcmdSettings *gcmd_settings_new (void);
  * be sure to change them also in gnome-cmd-data.c!
  */
 #define GCMD_PREF_GENERAL                             "org.gnome.gnome-commander.preferences.general"
-#define GCMD_SETTINGS_USE_DEFAULT_FONT                "use-default-font"
 #define GCMD_SETTINGS_PANEL_FONT                      "panel-font"
 #define GCMD_SETTINGS_SYSTEM_FONT                     "monospace-font-name"
 #define GCMD_SETTINGS_SIZE_DISP_MODE                  "size-display-mode"
@@ -68,7 +68,6 @@ GcmdSettings *gcmd_settings_new (void);
 #define GCMD_SETTINGS_MIDDLE_MOUSE_BUTTON_MODE        "middle-mouse-btn-mode"
 #define GCMD_SETTINGS_USE_TRASH                       "delete-to-trash"
 #define GCMD_SETTINGS_ICON_SIZE                       "icon-size"
-#define GCMD_SETTINGS_DEV_ICON_SIZE                   "dev-icon-size"
 #define GCMD_SETTINGS_ICON_SCALE_QUALITY              "icon-scale-quality"
 #define GCMD_SETTINGS_MIME_ICON_DIR                   "mime-icon-dir"
 #define GCMD_SETTINGS_CMDLINE_HISTORY                 "cmdline-history"
@@ -81,8 +80,6 @@ GcmdSettings *gcmd_settings_new (void);
 #define GCMD_SETTINGS_SHOW_BUTTONBAR                  "show-buttonbar"
 #define GCMD_SETTINGS_GUI_UPDATE_RATE                 "gui-update-rate"
 #define GCMD_SETTINGS_SYMLINK_PREFIX                  "symlink-string"
-#define GCMD_SETTINGS_MAIN_WIN_POS_X                  "main-win-pos-x"
-#define GCMD_SETTINGS_MAIN_WIN_POS_Y                  "main-win-pos-y"
 #define GCMD_SETTINGS_SAVE_DIRS_ON_EXIT               "save-dirs-on-exit"
 #define GCMD_SETTINGS_SAVE_TABS_ON_EXIT               "save-tabs-on-exit"
 #define GCMD_SETTINGS_SAVE_DIR_HISTORY_ON_EXIT        "save-dir-history-on-exit"
@@ -123,8 +120,12 @@ GcmdSettings *gcmd_settings_new (void);
 #define GCMD_SETTINGS_ADVRENAME_PROFILES_FORMAT_STRING "a(ssuiuuuasasab)"
 #define GCMD_SETTINGS_FILE_LIST_TABS                  "file-list-tabs"
 #define GCMD_SETTINGS_FILE_LIST_TAB_FORMAT_STRING     "(syybb)"
+// deprecated after v1.18.0
 #define GCMD_SETTINGS_DEVICES                         "devices"
+// deprecated after v1.18.0
 #define GCMD_SETTINGS_DEVICES_FORMAT_STRING           "(ssss)"
+#define GCMD_SETTINGS_DEVICE_LIST                     "device-list"
+#define GCMD_SETTINGS_DEVICE_LIST_FORMAT_STRING       "(sssv)"
 #define GCMD_SETTINGS_FAV_APPS                        "favorite-apps"
 #define GCMD_SETTINGS_FAV_APPS_FORMAT_STRING          "(ssssubbb)"
 #define GCMD_SETTINGS_DIRECTORY_HISTORY               "directory-history"
@@ -335,7 +336,6 @@ struct GnomeCmdData
         gboolean                     save_search_history_on_exit;
         gboolean                     search_window_is_transient {true};
         gchar                       *symlink_prefix;
-        gint                         main_win_pos[2];
         gboolean                     deleteToTrash;
         // Format
         GnomeCmdSizeDispMode         size_disp_mode;
@@ -400,7 +400,6 @@ struct GnomeCmdData
                    save_cmdline_history_on_exit(TRUE),
                    save_search_history_on_exit(TRUE),
                    symlink_prefix(nullptr),
-                   main_win_pos{0,25},
                    deleteToTrash(TRUE),
                    size_disp_mode(GNOME_CMD_SIZE_DISP_MODE_POWERED),
                    perm_disp_mode(GNOME_CMD_PERM_DISP_MODE_TEXT),
@@ -656,7 +655,7 @@ struct GnomeCmdData
         gint width {400}, height {250};
     };
 
-    typedef std::pair<std::string,triple<GnomeCmdFileList::ColumnID,GtkSortType,gboolean> > Tab;
+    typedef std::pair<std::string, std::tuple<GnomeCmdFileList::ColumnID,GtkSortType,gboolean> > Tab;
 
     static GSettingsSchemaSource* GetGlobalSchemaSource();
 
@@ -689,7 +688,7 @@ struct GnomeCmdData
     inline gint get_int (const gchar *path, int def);
     inline void set_string (const gchar *path, const gchar *value);
     inline gboolean get_bool (const gchar *path, gboolean def);
-    inline void set_color (const gchar *path, GdkColor *color);
+    inline void set_color (const gchar *path, GdkRGBA *color);
 
   public:
 
@@ -712,7 +711,6 @@ struct GnomeCmdData
     gboolean                     buttonbar_visibility {TRUE};
     gboolean                     mainmenu_visibility {TRUE};
 
-    guint                        dev_icon_size {16};
     guint                        fs_col_width[GnomeCmdFileList::NUM_COLUMNS];
     guint                        gui_update_rate;
 
@@ -753,10 +751,10 @@ struct GnomeCmdData
     void save_bookmarks();
     void load_bookmarks();
     void save();
-    gboolean gnome_cmd_data_parse_color (const gchar *spec, GdkColor *color);
-    gboolean set_color_if_valid_key_value(GdkColor *color, GSettings *settings, const char *key);
+    gboolean gnome_cmd_data_parse_color (const gchar *spec, GdkRGBA *color);
+    gboolean set_color_if_valid_key_value(GdkRGBA *color, GSettings *settings, const char *key);
     gboolean set_gsettings_when_changed (GSettings *settings, const char *key, gpointer value);
-    gboolean set_gsettings_color_when_changed (GSettings *settings, const char *key, GdkColor *color);
+    gboolean set_gsettings_color_when_changed (GSettings *settings, const char *key, GdkRGBA *color);
     gboolean set_gsettings_enum_when_changed (GSettings *settings, const char *key, gint value);
     gboolean is_valid_color_string(const char *colorstring);
     gboolean set_valid_color_string(GSettings *settings, const char* key);
@@ -769,9 +767,6 @@ gpointer gnome_cmd_data_get_con_list ();
 GList *gnome_cmd_data_get_auto_load_plugins ();
 void gnome_cmd_data_set_auto_load_plugins (GList *plugins);
 
-void gnome_cmd_data_get_main_win_pos (gint *x, gint *y);
-void gnome_cmd_data_set_main_win_pos (gint x, gint y);
-
 const gchar *gnome_cmd_data_get_symlink_prefix ();
 
 void on_use_default_font_changed();
