@@ -50,7 +50,7 @@ struct GnomeCmdXferProgressWinClass
 
 GtkWidget *gnome_cmd_xfer_progress_win_new (guint no_of_files=0);
 
-GtkType gnome_cmd_xfer_progress_win_get_type ();
+GType gnome_cmd_xfer_progress_win_get_type ();
 
 void gnome_cmd_xfer_progress_win_set_total_progress (GnomeCmdXferProgressWin *win,
                                                      guint64 file_bytes_copied,
