@@ -24,13 +24,11 @@
 
 #pragma once
 
-#define GVIEWER(obj)          GTK_CHECK_CAST (obj, gviewer_get_type (), GViewer)
-#define GVIEWER_CLASS(klass)  GTK_CHECK_CLASS_CAST (klass, gviewer_get_type (), GViewerClass)
-#define IS_GVIEWER(obj)       GTK_CHECK_TYPE (obj, gviewer_get_type ())
+#define GVIEWER(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gviewer_get_type (), GViewer)
+#define GVIEWER_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gviewer_get_type (), GViewerClass)
+#define IS_GVIEWER(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gviewer_get_type ())
 
-struct GViewerPrivate;
-
- enum VIEWERDISPLAYMODE
+enum VIEWERDISPLAYMODE
 {
     DISP_MODE_TEXT_FIXED,
     DISP_MODE_BINARY,
@@ -40,18 +38,17 @@ struct GViewerPrivate;
 
 struct GViewer
 {
-    GtkTable table;
-    GViewerPrivate *priv;
+    GtkGrid parent;
 };
 
 struct GViewerClass
 {
-    GtkTableClass parent_class;
+    GtkGridClass parent_class;
     void (*status_line_changed)  (GViewer *obj, const gchar *statusline);
 };
 
 GtkWidget     *gviewer_new ();
-GtkType        gviewer_get_type ();
+GType          gviewer_get_type ();
 void           gviewer_set_client (GViewer *obj, GtkWidget *client);
 GtkWidget     *gviewer_get_client (GViewer *obj);
 
@@ -92,6 +89,6 @@ void        gviewer_set_scale_factor(GViewer *obj, double scalefactor);
 double      gviewer_get_scale_factor(GViewer *obj);
 
 void        gviewer_image_operation(GViewer *obj, ImageRender::DISPLAYMODE op);
-void        gviewer_copy_selection(GtkMenuItem *item, GViewer *obj);
+void        gviewer_copy_selection(GViewer *obj);
 
 TextRender  *gviewer_get_text_render(GViewer *obj);
