@@ -40,8 +40,6 @@ using namespace std;
 
 
 static GList *plugins = nullptr;
-static GdkPixbuf *exec_pixbuf = nullptr;
-static GdkPixbuf *blank_pixbuf = nullptr;
 
 gchar* get_plugin_config_location();
 
@@ -123,10 +121,11 @@ static void activate_plugin (PluginData *data)
 
     data->active = TRUE;
 
+    GSimpleActionGroup *actions = gnome_cmd_plugin_create_actions (data->plugin, data->action_group_name);
+    gtk_widget_insert_action_group (*main_win, data->action_group_name, G_ACTION_GROUP (actions));
+
     GnomeCmdState *state = main_win->get_state();
     data->menu = gnome_cmd_plugin_create_main_menu (data->plugin, state);
-    if (data->menu)
-        main_win->add_plugin_menu(data);
 }
 
 
@@ -136,13 +135,14 @@ static void inactivate_plugin (PluginData *data)
         return;
 
     data->active = FALSE;
-    if (data->menu)
-        gtk_object_destroy (GTK_OBJECT (data->menu));
+    gtk_widget_insert_action_group (*main_win, data->action_group_name, nullptr);
+    g_clear_object (&data->menu);
 }
 
 
 static void scan_plugins_in_dir (const gchar *dpath)
 {
+    static int index = 0;
     auto gFileInfoList = sync_dir_list(dpath);
 
     if (g_list_length(gFileInfoList) == 0)
@@ -164,11 +164,13 @@ static void scan_plugins_in_dir (const gchar *dpath)
         data->active = FALSE;
         data->menu = nullptr;
         data->autoload = FALSE;
+        data->action_group_name = g_strdup_printf ("plugin%d", index++);
         activate_plugin (data);
         if (!data->loaded)
         {
             g_free (data->fname);
             g_free (data->fpath);
+            g_free (data->action_group_name);
             g_free (data);
         }
         else
@@ -213,13 +215,15 @@ void plugin_manager_init ()
         }
     }
 
-    // inactivate plugins that shouldn't be autoloaded
+    // deactivate plugins that shouldn't be autoloaded
     for (GList *l=plugins; l; l=l->next)
     {
         auto data = static_cast<PluginData*> (l->data);
         if (!data->autoload)
             inactivate_plugin (data);
     }
+
+    main_win->plugins_updated();
 }
 
 
@@ -289,6 +293,8 @@ static void update_plugin_list (GtkTreeView *view, GtkWidget *dialog)
     gboolean only_update = gtk_tree_model_get_iter_first (model, &iter);
     GtkListStore *store = GTK_LIST_STORE (model);
 
+    GIcon *exec_icon = g_themed_icon_new ("system-run");
+
     for (GList *i=plugins; i; i=i->next)
     {
         auto data = static_cast<PluginData*> (i->data);
@@ -296,7 +302,7 @@ static void update_plugin_list (GtkTreeView *view, GtkWidget *dialog)
         if (only_update)
         {
             gtk_list_store_set (store, &iter,
-                                0, data->active ? exec_pixbuf : blank_pixbuf,
+                                0, data->active ? exec_icon : nullptr,
                                 1, (gchar *) data->info->name,
                                 4, data,
                                 -1);
@@ -306,7 +312,7 @@ static void update_plugin_list (GtkTreeView *view, GtkWidget *dialog)
         {
             gtk_list_store_append (store, &iter);
             gtk_list_store_set (store, &iter,
-                                0, data->active ? exec_pixbuf : blank_pixbuf,
+                                0, data->active ? exec_icon : nullptr,
                                 1, (gchar *) data->info->name,
                                 2, (gchar *) data->info->version,
                                 3, data->fname,
@@ -332,6 +338,7 @@ inline void do_toggle (GtkWidget *dialog)
         activate_plugin (data);
 
     update_plugin_list (view, dialog);
+    main_win->plugins_updated();
 }
 
 
@@ -355,7 +362,7 @@ static void on_configure (GtkButton *button, GtkWidget *dialog)
     g_return_if_fail (data != nullptr);
     g_return_if_fail (data->active);
 
-    gnome_cmd_plugin_configure (data->plugin);
+    gnome_cmd_plugin_configure (data->plugin, GTK_WINDOW (dialog));
 }
 
 
@@ -368,30 +375,31 @@ static void on_about (GtkButton *button, GtkWidget *dialog)
 
     GtkWidget *about = gnome_cmd_about_plugin_new (data->info);
 
-    gtk_window_set_transient_for (GTK_WINDOW (about), *main_win);
-    g_object_ref (about);
-    gtk_widget_show (about);
+    gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (dialog));
+    gtk_window_present (GTK_WINDOW (about));
 }
 
 
 static void on_close (GtkButton *button, GtkWidget *dialog)
 {
-    gtk_widget_destroy (dialog);
+    gtk_window_destroy (GTK_WINDOW (dialog));
 }
 
 
-void plugin_manager_show ()
+void plugin_manager_show (GtkWindow *parent_window)
 {
     GtkWidget *dialog, *hbox, *bbox, *button;
     GtkListStore *avail_store;
     GtkWidget *avail_view;
 
-    dialog = gnome_cmd_dialog_new (_("Available plugins"));
+    dialog = gnome_cmd_dialog_new (parent_window, _("Available plugins"));
     g_object_ref (dialog);
 
     hbox = create_vbox (dialog, FALSE, 6);
-    avail_store = gtk_list_store_new (5, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER);
-    avail_view = create_treeview (dialog, "avail_view", GTK_TREE_MODEL (avail_store), 20, GTK_SIGNAL_FUNC (on_plugin_selection_changed), nullptr);
+    avail_store = gtk_list_store_new (5, G_TYPE_ICON, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER);
+    avail_view = create_treeview (dialog, "avail_view", GTK_TREE_MODEL (avail_store), 20, G_CALLBACK (on_plugin_selection_changed), nullptr);
+    gtk_widget_set_hexpand (GTK_WIDGET (avail_view), TRUE);
+    gtk_widget_set_vexpand (GTK_WIDGET (avail_view), TRUE);
     create_treeview_column (avail_view, 0, 20, "");
     create_treeview_column (avail_view, 1, 200, _("Name"));
     create_treeview_column (avail_view, 2, 50, _("Version"));
@@ -400,38 +408,31 @@ void plugin_manager_show ()
     bbox = create_hbuttonbox (dialog);
     gtk_button_box_set_layout (GTK_BUTTON_BOX (bbox), GTK_BUTTONBOX_START);
 
-    button = create_button (GTK_WIDGET (dialog), _("_Enable"), GTK_SIGNAL_FUNC (on_toggle));
+    button = create_button (GTK_WIDGET (dialog), _("_Enable"), G_CALLBACK (on_toggle));
     g_object_set_data (G_OBJECT (dialog), "toggle_button", button);
-    gtk_box_pack_start (GTK_BOX (bbox), button, TRUE, FALSE, 0);
+    gtk_box_append (GTK_BOX (bbox), button);
 
-    button = create_button (GTK_WIDGET (dialog), _("_Configure"), GTK_SIGNAL_FUNC (on_configure));
+    button = create_button (GTK_WIDGET (dialog), _("_Configure"), G_CALLBACK (on_configure));
     g_object_set_data (G_OBJECT (dialog), "conf_button", button);
     gtk_widget_set_sensitive (button, FALSE);
-    gtk_box_pack_start (GTK_BOX (bbox), button, TRUE, FALSE, 0);
+    gtk_box_append (GTK_BOX (bbox), button);
 
-    button = create_button (GTK_WIDGET (dialog), _("_About"), GTK_SIGNAL_FUNC (on_about));
+    button = create_button (GTK_WIDGET (dialog), _("_About"), G_CALLBACK (on_about));
     g_object_set_data (G_OBJECT (dialog), "about_button", button);
     gtk_widget_set_sensitive (button, FALSE);
-    gtk_box_pack_start (GTK_BOX (bbox), button, TRUE, FALSE, 0);
+    gtk_box_append (GTK_BOX (bbox), button);
 
-    gtk_box_pack_start (GTK_BOX (hbox), avail_view, TRUE, TRUE, 0);
-    gtk_box_pack_start (GTK_BOX (hbox), bbox, FALSE, TRUE, 0);
+    gtk_box_append (GTK_BOX (hbox), avail_view);
+    gtk_box_append (GTK_BOX (hbox), bbox);
 
     gnome_cmd_dialog_add_expanding_category (GNOME_CMD_DIALOG (dialog), hbox);
 
     avail_view = lookup_widget (avail_view, "avail_view");
     g_signal_connect (GTK_TREE_VIEW (avail_view), "row-activated", G_CALLBACK (on_plugin_activated), dialog);
 
-    if (!exec_pixbuf)
-        exec_pixbuf = IMAGE_get_pixbuf (PIXMAP_EXEC_WHEEL);
-
-    if (!blank_pixbuf)
-        blank_pixbuf = IMAGE_get_pixbuf (PIXMAP_FLIST_ARROW_BLANK);
-
     update_plugin_list (GTK_TREE_VIEW (avail_view), dialog);
 
-    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_SIGNAL_FUNC(on_close), dialog);
-    gtk_window_set_transient_for (GTK_WINDOW (dialog), *main_win);
+    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), _("_Close"), G_CALLBACK(on_close), dialog);
 
     gtk_widget_set_size_request (GTK_WIDGET (dialog), 500, 300);
     gtk_window_set_resizable ((GtkWindow *) GTK_WIDGET (dialog), TRUE);
